package javax.swing.border;

import java.awt.Graphics;
import java.awt.Component;
import java.awt.Insets;
import javax.swing.Icon;
import java.awt.Color;

public class MatteBorder extends EmptyBorder
{
    protected Color color;
    protected Icon tileIcon;
    
    public MatteBorder(int n, int n2, int n3, int n4, Color color) {
        super(n, n2, n3, n4);
        this.color = color;
    }
    
    public MatteBorder(Insets insets, Color color) {
        super(insets);
        this.color = color;
    }
    
    public MatteBorder(int n, int n2, int n3, int n4, Icon tileIcon) {
        super(n, n2, n3, n4);
        this.tileIcon = tileIcon;
    }
    
    public MatteBorder(Insets insets, Icon tileIcon) {
        super(insets);
        this.tileIcon = tileIcon;
    }
    
    public MatteBorder(Icon icon) {
        this(-1, -1, -1, -1, icon);
    }
    
    @Override
    public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
        Insets borderInsets = this.getBorderInsets(component);
        Color color = graphics.getColor();
        graphics.translate(n, n2);
        if (this.tileIcon != null) {
            this.color = ((this.tileIcon.getIconWidth() == -1) ? Color.gray : null);
        }
        if (this.color != null) {
            graphics.setColor(this.color);
            graphics.fillRect(0, 0, n3 - borderInsets.right, borderInsets.top);
            graphics.fillRect(0, borderInsets.top, borderInsets.left, n4 - borderInsets.top);
            graphics.fillRect(borderInsets.left, n4 - borderInsets.bottom, n3 - borderInsets.left, borderInsets.bottom);
            graphics.fillRect(n3 - borderInsets.right, 0, borderInsets.right, n4 - borderInsets.bottom);
        }
        else if (this.tileIcon != null) {
            int iconWidth = this.tileIcon.getIconWidth();
            int iconHeight = this.tileIcon.getIconHeight();
            this.paintEdge(component, graphics, 0, 0, n3 - borderInsets.right, borderInsets.top, iconWidth, iconHeight);
            this.paintEdge(component, graphics, 0, borderInsets.top, borderInsets.left, n4 - borderInsets.top, iconWidth, iconHeight);
            this.paintEdge(component, graphics, borderInsets.left, n4 - borderInsets.bottom, n3 - borderInsets.left, borderInsets.bottom, iconWidth, iconHeight);
            this.paintEdge(component, graphics, n3 - borderInsets.right, 0, borderInsets.right, n4 - borderInsets.bottom, iconWidth, iconHeight);
        }
        graphics.translate(-n, -n2);
        graphics.setColor(color);
    }
    
    private void paintEdge(Component component, Graphics create, int i, int j, int width, int height, int n, int n2) {
        create = create.create(i, j, width, height);
        int n3 = -(j % n2);
        for (i = -(i % n); i < width; i += n) {
            for (j = n3; j < height; j += n2) {
                this.tileIcon.paintIcon(component, create, i, j);
            }
        }
        create.dispose();
    }
    
    @Override
    public Insets getBorderInsets(Component component, Insets insets) {
        return this.computeInsets(insets);
    }
    
    @Override
    public Insets getBorderInsets() {
        return this.computeInsets(new Insets(0, 0, 0, 0));
    }
    
    private Insets computeInsets(Insets insets) {
        if (this.tileIcon != null && this.top == -1 && this.bottom == -1 && this.left == -1 && this.right == -1) {
            int iconWidth = this.tileIcon.getIconWidth();
            int iconHeight = this.tileIcon.getIconHeight();
            insets.top = iconHeight;
            insets.right = iconWidth;
            insets.bottom = iconHeight;
            insets.left = iconWidth;
            return insets;
        }
        insets.left = this.left;
        insets.top = this.top;
        insets.right = this.right;
        insets.bottom = this.bottom;
        return insets;
    }
    
    public Color getMatteColor() {
        return this.color;
    }
    
    public Icon getTileIcon() {
        return this.tileIcon;
    }
    
    @Override
    public boolean isBorderOpaque() {
        return this.color != null;
    }
}
